pub struct BoxStyle {
pub top_left: Cell,
pub top_right: Cell,
pub bottom_right: Cell,
pub bottom_left: Cell,
pub horizontal: Cell,
pub vertical: Cell,
}Expand description
Fields
top_left: CellTop-left corner character.
top_right: CellTop-right corner character.
bottom_right: CellBottom-right corner character.
bottom_left: CellBottom-left corner character.
horizontal: CellHorizontal line character.
vertical: CellVertical line character.
Implementations
Sourceimpl BoxStyle
impl BoxStyle
Sourcepub fn render(&self, rect: Rect, buf: &mut DoubleBuffer) -> Rect
pub fn render(&self, rect: Rect, buf: &mut DoubleBuffer) -> Rect
Renders a complete box border within the given rectangle.
Returns the inner rectangle after subtracting the border.
Sourcepub fn render_partial(
&self,
rect: Rect,
buf: &mut DoubleBuffer,
set: RelSet,
) -> Rect
pub fn render_partial( &self, rect: Rect, buf: &mut DoubleBuffer, set: RelSet, ) -> Rect
Renders only the specified parts of a box border.
Returns the inner rectangle after subtracting the rendered edges.